orders: Order Data from the Contonso Dataset

ordersR Documentation

Order Data from the Contonso Dataset

Description

This dataset contains information about customer orders, including order dates, delivery dates, and store details.

Usage

orders

Format

A data frame with 5 columns:

order_key

double Unique identifier for the order.

customer_key

double Unique identifier for the customer who placed the order.

store_key

double Unique identifier for the store where the order was placed.

order_date

Date The date when the order was placed.

delivery_date

Date The date when the order is expected to be delivered.

currency_code

character The currency code used for the order (e.g., USD, EUR).

https://github.com/sql-bi/Contoso-Data-Generator-V2-Data/releases/tag/ready-to-use-data


contoso documentation built on Feb. 4, 2026, 9:07 a.m.