This dataset contains information about sales orders, including order details, pricing, and customer data from the Contonso dataset. It provides insights into the transactions that have occurred, including order dates, delivery dates, customer and store information, as well as product details.
salesA data frame with sales columns:
double Unique identifier for each order.
double Line number within the order (for multi-line orders).
Date Date when the order was placed.
Date Date when the order was delivered.
double Unique identifier for the customer who placed the order.
double Unique identifier for the store where the order was placed.
double Unique identifier for the product in the order.
double The quantity of the product ordered.
double The price per unit of the product.
double The total net price for the product, considering any discounts.
double The cost per unit of the product.
character The currency code used for the transaction (e.g., USD, EUR).
double The exchange rate applied to the currency, if applicable.
double A product's unit_price multiplied by quantity.
double A product's net_price multiplied by quantity.
double A product's unit_price minute net_price.
double A product's unit_discount multiplied by quantity.
double A product's unit_cost multiplied by quantity.
double A product's net_revenue minus cogs.
double A product margin divided by quantity.